pub struct MessageDelivery {
pub stream: Option<String>,
pub consumer: Option<String>,
pub attempt: u64,
}Expand description
Re-exported public API. Durable transport delivery details attached to an event handler invocation.
Fields
stream: Option<String>The stream that delivered the message, when applicable.
consumer: Option<String>The durable consumer that delivered the message, when applicable.
attempt: u64The one-based delivery attempt.