MessageHandlerDef

Struct MessageHandlerDef 

pub struct MessageHandlerDef {
    pub kind: MessageHandlerKind,
    pub pattern: &'static str,
    /* private fields */
}
Re-exported public API. One transport-neutral message handler declared by a microservice.

Fields

kind: MessageHandlerKind

Whether the handler is a command or event handler.

pattern: &'static str

The logical subject pattern.

Implementations

Source

impl MessageHandlerDef

pub fn new( kind: MessageHandlerKind, pattern: &'static str, invoke: impl for<'a> Fn(&'a Container, MessageContext, Value) -> BoxFuture<'a, Result<Option<Value>>> + Send + Sync + 'static, ) -> Self

Builds a handler definition. This is primarily used by #[microservice].

pub fn invoke<'a>( &self, container: &'a Container, context: MessageContext, payload: Value, ) -> BoxFuture<'a, Result<Option<Value>>>

Invokes the typed handler after the transport has decoded its envelope.