RegisteredWebSocketGateway

Trait RegisteredWebSocketGateway 

pub trait RegisteredWebSocketGateway: WebSocketGateway + Gateway { }
Re-exported public API. Marker implemented by #[gateway] for RFC 6455 gateways. It separates path metadata from the transport callbacks so the same ModuleMetadata::gateway registration API can also support optional transports such as Socket.IO.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors