Crate caelix_core

Crate caelix_core 

Core primitives for Caelix.

Re-exports

pub use validator;

Macros

provider_dependencies
Declares provider dependencies for manual Injectable implementations and factories.

Structs

BadGatewayException
BadRequestException
Bytes
A cheaply cloneable and sliceable chunk of contiguous memory.
Cache
CacheModule
ConflictException
Container
ControllerDef
EventBus
EventHandlerDef
EventModule
ExpectationFailedException
FailedDependencyException
ForbiddenException
GatewayDef
GatewayTimeoutException
GoneException
HttpException
HttpResponse
HttpVersionNotSupportedException
ImATeapotException
InsufficientStorageException
InternalServerErrorException
LengthRequiredException
LockedException
Logger
LoopDetectedException
MemoryCacheOptions
MemoryCacheStore
MethodNotAllowedException
MisdirectedRequestException
ModuleDef
ModuleMetadata
NetworkAuthenticationRequiredException
Next
NotAcceptableException
NotExtendedException
NotFoundException
NotImplementedException
PayloadTooLargeException
PaymentRequiredException
PreconditionFailedException
PreconditionRequiredException
ProviderDef
ProviderDependency
Metadata for one resolved provider dependency.
ProviderOverrides
ProxyAuthenticationRequiredException
RangeNotSatisfiableException
RequestContext
RequestHeaderFieldsTooLargeException
RequestTimeoutException
RouteDef
ServiceUnavailableException
StatusCode
An HTTP status code (status-code in RFC 9110 et al.).
TooEarlyException
TooManyRequestsException
UnauthorizedException
UnavailableForLegalReasonsException
UnprocessableEntityException
UnsupportedMediaTypeException
UpgradeRequiredException
UriTooLongException
VariantAlsoNegotiatesException
WebSocketCloseFrame
WebSocketError
WebSocketRequest
WebSocketSession

Enums

Body
A body whose shape isn’t known at the Response<T> type level — used by Response::Raw so a handler can return e.g. Response<()> while still sending an arbitrary JSON/text/bytes payload.
LogLevel
Response
ResponseBody
Response body: fully buffered, or a live stream of chunks.
WebSocketCloseCode

Traits

CacheStore
Controller
EventHandler
Gateway
Guard
Injectable
Interceptor
IntoCaelixResponse
Module
RegisterableEventHandler
RegisteredWebSocketGateway
Marker implemented by #[gateway] for RFC 6455 gateways. It separates path metadata from the transport callbacks so the same ModuleMetadata::gateway registration API can also support optional transports such as Socket.IO.
StreamExt
An extension trait for Streams that provides a variety of convenient combinator functions.
WebSocketGateway

Functions

bootstrap_module
build_container
build_container_with_overrides
dropped_http_request_logs
Returns the number of enabled HTTP access-log entries dropped because the asynchronous writer queue was full.
http_request_logging_enabled
log
log_application_started
log_application_starting
log_controller_routes
log_http_exception
log_http_request
log_listening
log_module_initialized
log_module_routes
log_provider_initialized
log_route_mapped
register_module
register_module_controllers
shutdown_module
validate_module_providers
visit_module_gateways

Type Aliases

BoxBodyStream
Async sequence of body chunks. Errors use framework HttpException.
BoxFuture
Result