Core primitives for Caelix.
Re-exports
pub use validator;
Macros
- provider_
dependencies - Declares provider dependencies for manual
Injectableimplementations and factories.
Structs
- BadGateway
Exception - BadRequest
Exception - Bytes
- A cheaply cloneable and sliceable chunk of contiguous memory.
- Cache
- Cache
Module - Conflict
Exception - Container
- Controller
Def - Event
Bus - Event
Handler Def - Event
Module - Expectation
Failed Exception - Failed
Dependency Exception - Forbidden
Exception - Gateway
Def - Gateway
Timeout Exception - Gone
Exception - Http
Exception - Http
Response - Http
Version NotSupported Exception - ImATeapot
Exception - Insufficient
Storage Exception - Internal
Server Error Exception - Length
Required Exception - Locked
Exception - Logger
- Loop
Detected Exception - Memory
Cache Options - Memory
Cache Store - Method
NotAllowed Exception - Misdirected
Request Exception - Module
Def - Module
Metadata - Network
Authentication Required Exception - Next
- NotAcceptable
Exception - NotExtended
Exception - NotFound
Exception - NotImplemented
Exception - Payload
TooLarge Exception - Payment
Required Exception - Precondition
Failed Exception - Precondition
Required Exception - Provider
Def - Provider
Dependency - Metadata for one resolved provider dependency.
- Provider
Overrides - Proxy
Authentication Required Exception - Range
NotSatisfiable Exception - Request
Context - Request
Header Fields TooLarge Exception - Request
Timeout Exception - Route
Def - Service
Unavailable Exception - Status
Code - An HTTP status code (
status-codein RFC 9110 et al.). - TooEarly
Exception - TooMany
Requests Exception - Unauthorized
Exception - Unavailable
ForLegal Reasons Exception - Unprocessable
Entity Exception - Unsupported
Media Type Exception - Upgrade
Required Exception - UriToo
Long Exception - Variant
Also Negotiates Exception - WebSocket
Close Frame - WebSocket
Error - WebSocket
Request - WebSocket
Session
Enums
- Body
- A body whose shape isn’t known at the
Response<T>type level — used byResponse::Rawso a handler can return e.g.Response<()>while still sending an arbitrary JSON/text/bytes payload. - LogLevel
- Response
- Response
Body - Response body: fully buffered, or a live stream of chunks.
- WebSocket
Close Code
Traits
- Cache
Store - Controller
- Event
Handler - Gateway
- Guard
- Injectable
- Interceptor
- Into
Caelix Response - Module
- Registerable
Event Handler - Registered
WebSocket Gateway - Marker implemented by
#[gateway]for RFC 6455 gateways. It separates path metadata from the transport callbacks so the sameModuleMetadata::gatewayregistration API can also support optional transports such as Socket.IO. - Stream
Ext - An extension trait for
Streams that provides a variety of convenient combinator functions. - WebSocket
Gateway
Functions
- bootstrap_
module - build_
container - build_
container_ with_ overrides - dropped_
http_ request_ logs - Returns the number of enabled HTTP access-log entries dropped because the asynchronous writer queue was full.
- http_
request_ logging_ enabled - log
- log_
application_ started - log_
application_ starting - log_
controller_ routes - log_
http_ exception - log_
http_ request - log_
listening - log_
module_ initialized - log_
module_ routes - log_
provider_ initialized - log_
route_ mapped - register_
module - register_
module_ controllers - shutdown_
module - validate_
module_ providers - visit_
module_ gateways
Type Aliases
- BoxBody
Stream - Async sequence of body chunks. Errors use framework
HttpException. - BoxFuture
- Result